==> nipper-0.10.4.tgz: nipper-0.10.4/ScreenOS/process-address.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


struct mappingSOS			// Name Mappings
{
	char name[32];
	char address[64];
	char netMask[16];
	char comment[64];
	struct mappingSOS *next;
};

struct addressSOS			// NetScreenOS Zone Address Name Mapping Configuration
{
	char zone[32];
	struct mappingSOS *mapping;
	struct addressSOS *next;
};



// Process address lines
void processSOSAddress(char *line, struct nipperConfig *nipper)
{
	// Variables
	char tempString[nipper->maxSize];
	int position;
	struct ciscoCommand command;
	struct addressSOS *addressSOSPointer;
	struct mappingSOS *mappingSOSPointer;

	// Debug Mode
	if (nipper->debugMode == true)
		printf("Address Line: %s\n", line);

	// Init
	position = 2;
	command = splitLine(line);

	// If first address
	if (nipper->sos->nameList == 0)
	{
		// Create
		nipper->sos->nameList = malloc(sizeof(struct addressSOS));
		// Init
		memset(nipper->sos->nameList, 0 , sizeof(struct addressSOS));
		stripQuotes(command.part[position], tempString, nipper->maxSize);
		strncpy(nipper->sos->nameList->zone, tempString, sizeof(nipper->sos->nameList->zone) - 1);
		// Pointer
		addressSOSPointer = nipper->sos->nameList;
	}
	else
	{
		// Search for the zone
		addressSOSPointer = nipper->sos->nameList;
		stripQuotes(command.part[position], tempString, nipper->maxSize);
		while ((addressSOSPointer->next != 0) && (strcmp(addressSOSPointer->zone, tempString) != 0))
			addressSOSPointer = addressSOSPointer->next;

		// If not found
		if (strcmp(addressSOSPointer->zone, tempString) != 0)
		{
			// Create
			addressSOSPointer->next = malloc(sizeof(struct addressSOS));
			// Init
			memset(addressSOSPointer->next, 0 , sizeof(struct addressSOS));
			stripQuotes(command.part[position], tempString, nipper->maxSize);
			strncpy(addressSOSPointer->next->zone, tempString, sizeof(addressSOSPointer->next->zone) - 1);
			// Pointer
			addressSOSPointer = addressSOSPointer->next;
		}
	}
	position++;

	// Add Name Mapping
	if (addressSOSPointer->mapping == 0)
	{
		// Create
		addressSOSPointer->mapping = malloc(sizeof(struct mappingSOS));
		// Init
		memset(addressSOSPointer->mapping, 0 , sizeof(struct mappingSOS));
		// Pointer
		mappingSOSPointer = addressSOSPointer->mapping;
	}
	else
	{
		// Find last mapping
		mappingSOSPointer = addressSOSPointer->mapping;
		while (mappingSOSPointer->next != 0)
			mappingSOSPointer = mappingSOSPointer->next;
		// Create
		mappingSOSPointer->next = malloc(sizeof(struct mappingSOS));
		// Init
		memset(mappingSOSPointer->next, 0 , sizeof(struct mappingSOS));
		// Pointer
		mappingSOSPointer = mappingSOSPointer->next;
	}

	// Get Mapping Name
	stripQuotes(command.part[position], tempString, nipper->maxSize);
	strncpy(mappingSOSPointer->name, tempString, sizeof(mappingSOSPointer->name) - 1);
	position++;

	// Get Mapping Address / FQDN
	stripQuotes(command.part[position], tempString, nipper->maxSize);
	strncpy(mappingSOSPointer->address, tempString, sizeof(mappingSOSPointer->address) - 1);
	position++;

	// Was a FQDN or CIDR not used
	if ((mappingSOSPointer->address[0] > 47) && (mappingSOSPointer->address[0] < 58) && (strchr(mappingSOSPointer->address, '/') == 0))
	{
		// Get netmask
		stripQuotes(command.part[position], tempString, nipper->maxSize);
		strncpy(mappingSOSPointer->netMask, tempString, sizeof(mappingSOSPointer->netMask) - 1);
		position++;
	}

	// If there is a comment
	if (position < command.parts)
	{
		stripQuotes(command.part[position], tempString, nipper->maxSize);
		strncpy(mappingSOSPointer->comment, tempString, sizeof(mappingSOSPointer->comment) - 1);
	}
}

==> nipper-0.10.5.tgz: nipper-0.10.5/ScreenOS/process-address.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


struct mappingSOS			// Name Mappings
{
	char name[32];
	char address[64];
	char netMask[16];
	char comment[64];
	struct mappingSOS *next;
};

struct addressSOS			// NetScreenOS Zone Address Name Mapping Configuration
{
	char zone[32];
	struct mappingSOS *mapping;
	struct addressSOS *next;
};



// Process address lines
void processSOSAddress(char *line, struct nipperConfig *nipper)
{
	// Variables
	char tempString[nipper->maxSize];
	int position = 0;
	struct ciscoCommand command;
	struct addressSOS *addressSOSPointer = 0;
	struct mappingSOS *mappingSOSPointer = 0;

	// Debug Mode
	if (nipper->debugMode == true)
		printf("Address Line: %s\n", line);

	// Init
	position = 2;
	command = splitLine(line);

	// If first address
	if (nipper->sos->nameList == 0)
	{
		// Create
		nipper->sos->nameList = malloc(sizeof(struct addressSOS));
		// Init
		memset(nipper->sos->nameList, 0 , sizeof(struct addressSOS));
		stripQuotes(command.part[position], tempString, nipper->maxSize);
		strncpy(nipper->sos->nameList->zone, tempString, sizeof(nipper->sos->nameList->zone) - 1);
		// Pointer
		addressSOSPointer = nipper->sos->nameList;
	}
	else
	{
		// Search for the zone
		addressSOSPointer = nipper->sos->nameList;
		stripQuotes(command.part[position], tempString, nipper->maxSize);
		while ((addressSOSPointer->next != 0) && (strcmp(addressSOSPointer->zone, tempString) != 0))
			addressSOSPointer = addressSOSPointer->next;

		// If not found
		if (strcmp(addressSOSPointer->zone, tempString) != 0)
		{
			// Create
			addressSOSPointer->next = malloc(sizeof(struct addressSOS));
			// Init
			memset(addressSOSPointer->next, 0 , sizeof(struct addressSOS));
			stripQuotes(command.part[position], tempString, nipper->maxSize);
			strncpy(addressSOSPointer->next->zone, tempString, sizeof(addressSOSPointer->next->zone) - 1);
			// Pointer
			addressSOSPointer = addressSOSPointer->next;
		}
	}
	position++;

	// Add Name Mapping
	if (addressSOSPointer->mapping == 0)
	{
		// Create
		addressSOSPointer->mapping = malloc(sizeof(struct mappingSOS));
		// Init
		memset(addressSOSPointer->mapping, 0 , sizeof(struct mappingSOS));
		// Pointer
		mappingSOSPointer = addressSOSPointer->mapping;
	}
	else
	{
		// Find last mapping
		mappingSOSPointer = addressSOSPointer->mapping;
		while (mappingSOSPointer->next != 0)
			mappingSOSPointer = mappingSOSPointer->next;
		// Create
		mappingSOSPointer->next = malloc(sizeof(struct mappingSOS));
		// Init
		memset(mappingSOSPointer->next, 0 , sizeof(struct mappingSOS));
		// Pointer
		mappingSOSPointer = mappingSOSPointer->next;
	}

	// Get Mapping Name
	stripQuotes(command.part[position], tempString, nipper->maxSize);
	strncpy(mappingSOSPointer->name, tempString, sizeof(mappingSOSPointer->name) - 1);
	position++;

	// Get Mapping Address / FQDN
	stripQuotes(command.part[position], tempString, nipper->maxSize);
	strncpy(mappingSOSPointer->address, tempString, sizeof(mappingSOSPointer->address) - 1);
	position++;

	// Was a FQDN or CIDR not used
	if ((mappingSOSPointer->address[0] > 47) && (mappingSOSPointer->address[0] < 58) && (strchr(mappingSOSPointer->address, '/') == 0))
	{
		// Get netmask
		stripQuotes(command.part[position], tempString, nipper->maxSize);
		strncpy(mappingSOSPointer->netMask, tempString, sizeof(mappingSOSPointer->netMask) - 1);
		position++;
	}

	// If there is a comment
	if (position < command.parts)
	{
		stripQuotes(command.part[position], tempString, nipper->maxSize);
		strncpy(mappingSOSPointer->comment, tempString, sizeof(mappingSOSPointer->comment) - 1);
	}
}
